@@ -55,6 +55,11 @@ configurations = (
             "-moz-animation-duration",
             "-khtml-animation-duration",
             "-webkit-animation-duration",
+            "animation-name",
+            "-o-animation-name",
+            "-ms-animation-name",
+            "-moz-animation-name",
+            "-khtml-animation-name",
             "-webkit-animation-name",
             "appearance",
             "-o-appearance",
@@ -69,6 +74,10 @@ configurations = (
             "-webkit-backface-visibility",
             "background",
             "background-attachment",
+            "background-clip",
+            "-o-background-clip",
+            "-ms-background-clip",
+            "-moz-background-clip",
             "-webkit-background-clip",
             "background-color",
             "background-image",
@@ -81,8 +90,14 @@ configurations = (
             "border-bottom",
             "border-bottom-color",
             "border-bottom-left-radius",
+            "-o-border-bottom-left-radius",
+            "-ms-border-bottom-left-radius",
+            "-moz-border-bottom-left-radius",
             "-webkit-border-bottom-left-radius",
             "border-bottom-right-radius",
+            "-o-border-bottom-right-radius",
+            "-ms-border-bottom-right-radius",
+            "-moz-border-bottom-right-radius",
             "-webkit-border-bottom-right-radius",
             "border-bottom-style",
             "border-bottom-width",
@@ -111,8 +126,14 @@ configurations = (
             "border-top",
             "border-top-color",
             "border-top-left-radius",
+            "-ms-border-top-left-radius",
+            "-moz-border-top-left-radius",
+            "-khtml-border-top-left-radius",
             "-webkit-border-top-left-radius",
             "border-top-right-radius",
+            "-ms-border-top-right-radius",
+            "-moz-border-top-right-radius",
+            "-khtml-border-top-right-radius",
             "-webkit-border-top-right-radius",
             "border-top-style",
             "border-top-width",
@@ -134,14 +155,12 @@ configurations = (
             "-moz-column-count",
             "-khtml-column-count",
             "-webkit-column-count",
-            "-webkit-column-count",
             "column-gap",
             "-o-column-gap",
             "-ms-column-gap",
             "-moz-column-gap",
             "-khtml-column-gap",
             "-webkit-column-gap",
-            "-webkit-column-gap",
             "content",
             "counter-increment",
             "counter-reset",
@@ -153,6 +172,12 @@ configurations = (
             "display",
             "elevation",
             "empty-cells",
+            "filter",
+            "-o-filter",
+            "-ms-filter",
+            "-moz-filter",
+            "-khtml-filter",
+            "-webkit-filter",
             "float",
             "font-family",
             "font-size",
@@ -195,7 +220,6 @@ configurations = (
             "-moz-osx-font-smoothing",
             "-khtml-osx-font-smoothing",
             "-webkit-osx-font-smoothing",
-            "-webkit-osx-font-smoothing",
             "outline-color",
             "outline-offset",
             "outline-style",
@@ -215,10 +239,21 @@ configurations = (
             "pause-after",
             "pause-before",
             "pause",
+            "perspective",
+            "-o-perspective",
+            "-ms-perspective",
+            "-moz-perspective",
+            "-khtml-perspective",
             "-webkit-perspective",
             "pitch-range",
             "pitch",
             "play-during",
+            "print-color-adjust",
+            "-o-print-color-adjust",
+            "-ms-print-color-adjust",
+            "-moz-print-color-adjust",
+            "-khtml-print-color-adjust",
+            "-webkit-print-color-adjust",
             "pointer-events",
             "position",
             "quotes",
@@ -245,6 +280,9 @@ configurations = (
             "text-align",
             "text-decoration",
             "text-fill-color",
+            "-o-text-fill-color",
+            "-ms-text-fill-color",
+            "-moz-text-fill-color",
             "-webkit-text-fill-color",
             "text-indent",
             "text-overflow",
@@ -261,6 +299,15 @@ configurations = (
             "-ms-transform",
             "-moz-transform",
             "-webkit-transform",
+            "transform-origin",
+            "-o-transform-origin",
+            "-ms-transform-origin",
+            "-moz-transform-origin",
+            "-webkit-transform-origin",
+            "transform-style",
+            "-o-transform-style",
+            "-ms-transform-style",
+            "-moz-transform-style",
             "-webkit-transform-style",
             "transition",
             "-o-transition",
